package org.checkerframework.framework.test.junit;

import java.io.File;
import java.util.List;
import org.checkerframework.framework.test.CheckerFrameworkPerDirectoryTest;
import org.junit.runners.Parameterized.Parameters;

public class ReportTreeKindsTest extends CheckerFrameworkPerDirectoryTest {

  /**
   * @param testFiles the files containing test code, which will be type-checked
   */
  public ReportTreeKindsTest(List<File> testFiles) {
    super(
        testFiles,
        org.checkerframework.common.util.count.report.ReportChecker.class,
        "report",
        "-AreportTreeKinds=WHILE_LOOP,CONDITIONAL_AND");
  }

  @Parameters
  public static String[] getTestDirs() {
    return new String[] {"reporttreekinds"};
  }
}
